{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "salmon",
                "quant"
            ],
            "inputs": [
                {
                    "id": "#salmon-quant.cwl/index",
                    "type": "Directory",
                    "inputBinding": {
                        "position": -2,
                        "prefix": "-i",
                        "shellQuote": false
                    }
                },
                {
                    "id": "#salmon-quant.cwl/inf1",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-1",
                        "shellQuote": false
                    }
                },
                {
                    "id": "#salmon-quant.cwl/inf2",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-2",
                        "shellQuote": false
                    }
                },
                {
                    "default": "A",
                    "id": "#salmon-quant.cwl/libType",
                    "type": "string",
                    "inputBinding": {
                        "position": -2,
                        "prefix": "-l",
                        "shellQuote": false
                    }
                },
                {
                    "id": "#salmon-quant.cwl/quantdir",
                    "type": "string",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-o",
                        "shellQuote": false
                    }
                },
                {
                    "id": "#salmon-quant.cwl/runThreadN",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-p",
                        "shellQuote": false
                    },
                    "doc": "1\nint: number of threads to run Salmon\n"
                },
                {
                    "id": "#salmon-quant.cwl/gcBias",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--gcBias"
                    }
                },
                {
                    "id": "#salmon-quant.cwl/validateMappings",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--validateMappings"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "combinelab/salmon:1.1.0"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "id": "#salmon-quant.cwl",
            "outputs": [
                {
                    "id": "#salmon-quant.cwl/output_quantdir",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.quantdir)"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "STAR",
                "--runMode",
                "alignReads"
            ],
            "inputs": [
                {
                    "id": "#star_mapping-pe.cwl/fq1",
                    "type": "File",
                    "inputBinding": {
                        "position": 50,
                        "prefix": "--readFilesIn"
                    },
                    "label": "path to file that contain input read1",
                    "doc": "path to file that contain input read1"
                },
                {
                    "id": "#star_mapping-pe.cwl/fq2",
                    "type": "File",
                    "inputBinding": {
                        "position": 51
                    },
                    "label": "path to file that contain input read2",
                    "doc": "path to file that contain input read2"
                },
                {
                    "id": "#star_mapping-pe.cwl/genomeDir",
                    "type": "Directory",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--genomeDir",
                        "shellQuote": false
                    },
                    "label": "path to the directory where genome files are stored",
                    "doc": "path to the directory where genome files are stored"
                },
                {
                    "id": "#star_mapping-pe.cwl/nthreads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--runThreadN",
                        "shellQuote": false
                    },
                    "label": "Number of threads",
                    "doc": "defines the number of threads to be used for genome generation, it has to be set to the number of available cores on the server node."
                },
                {
                    "default": "Within",
                    "id": "#star_mapping-pe.cwl/outSAMunmapped",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--outSAMunmapped",
                        "shellQuote": false
                    },
                    "label": "output of unmapped reads in the SAM format",
                    "doc": "1st word: None: no output, Within: output unmapped reads within the main SAM file (i.e. Aligned.out.sam). 2nd word: KeepPairs: record unmapped mate for each alignment, and, in case of unsorted output, keep it adjacent to its mapped mate. Only a\u21b5ects multi-mapping reads."
                },
                {
                    "default": "STAR",
                    "id": "#star_mapping-pe.cwl/output_dir_name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "Name of the directory to write output files in",
                    "doc": "Name of the directory to write output files in"
                },
                {
                    "id": "#star_mapping-pe.cwl/outFileNamePrefix",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--outFileNamePrefix",
                        "shellQuote": false
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/readFilesCommand",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--readFilesCommand",
                        "shellQuote": false
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/outSAMtype",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--outSAMtype",
                        "shellQuote": false
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#star_mapping-pe.cwl/aligned",
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outSAMtype == \"BAM Unsorted\")\n    return p+\"Aligned.out.bam\";\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Aligned.sortedByCoord.out.bam\";\n}\n"
                    },
                    "secondaryFiles": [
                        "${\n   var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n   return [\n     {\"path\": p+\"Log.final.out\", \"class\":\"File\"},\n     {\"path\": p+\"SJ.out.tab\", \"class\":\"File\"},\n     {\"path\": p+\"Log.out\", \"class\":\"File\"}\n   ];\n}\n"
                    ]
                },
                {
                    "id": "#star_mapping-pe.cwl/bamRemDups",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.bamRemoveDuplicatesType != \"UniqueIdentical\")\n    return null;\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Processed.out.bam\";\n}\n"
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/mappingstats",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "${\n  var p = inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Log.final.out\";\n}\n"
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/readspergene",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"ReadsPerGene.out.tab\";\n}\n"
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/transcriptomesam",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Aligned.toTranscriptome.out.bam\";\n}\n"
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/Log.out",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${   var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";   return p+\"Log.out\"; }"
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/Log.progress.out",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"Log.progress.out\";\n}\n"
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/SJ.out.tab",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  var p=inputs.outFileNamePrefix?inputs.outFileNamePrefix:\"\";\n  return p+\"SJ.out.tab\";\n}\n"
                    }
                },
                {
                    "id": "#star_mapping-pe.cwl/unmapped",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.outSAMunmapped)"
                    }
                }
            ],
            "doc": "STAR: Spliced Transcripts Alignment to a Reference. https://github.com/alexdobin/STAR/blob/master/doc/STARmanual.pdf",
            "label": "STAR mapping: running mapping jobs.",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.genomeDir)",
                            "writable": true
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/star:2.7.1a--0"
                }
            ],
            "id": "#star_mapping-pe.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ],
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0"
        },
        {
            "class": "Workflow",
            "id": "#main",
            "doc": "STAR mapping and salmon quantification for one specified virus. Prepare using create_singlevirus.cwl beforehand. version 1.1",
            "label": "VIRTUS.PE.singlevirus",
            "inputs": [
                {
                    "id": "#main/fq2_unmapped",
                    "type": "File",
                    "https://www.sevenbridges.com/x": -620,
                    "https://www.sevenbridges.com/y": -304
                },
                {
                    "id": "#main/fq1_unmapped",
                    "type": "File",
                    "https://www.sevenbridges.com/x": -623,
                    "https://www.sevenbridges.com/y": -175
                },
                {
                    "id": "#main/genomeDir_singlevirus",
                    "type": "Directory",
                    "https://www.sevenbridges.com/x": -619,
                    "https://www.sevenbridges.com/y": -446
                },
                {
                    "id": "#main/salmon_index_singlevirus",
                    "type": "Directory",
                    "https://www.sevenbridges.com/x": -631,
                    "https://www.sevenbridges.com/y": -699
                },
                {
                    "id": "#main/quantdir",
                    "type": "string",
                    "https://www.sevenbridges.com/x": -631,
                    "https://www.sevenbridges.com/y": -821
                },
                {
                    "id": "#main/outFileNamePrefix_star",
                    "type": [
                        "null",
                        "string"
                    ],
                    "https://www.sevenbridges.com/x": -622,
                    "https://www.sevenbridges.com/y": -568
                },
                {
                    "id": "#main/runThreadN",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://www.sevenbridges.com/x": -632,
                    "https://www.sevenbridges.com/y": -24
                }
            ],
            "outputs": [
                {
                    "id": "#main/SJ.out.tab",
                    "outputSource": [
                        "#main/star_mapping_pe/SJ.out.tab"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://www.sevenbridges.com/x": -106,
                    "https://www.sevenbridges.com/y": -420
                },
                {
                    "id": "#main/mappingstats",
                    "outputSource": [
                        "#main/star_mapping_pe/mappingstats"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://www.sevenbridges.com/x": -106.39886474609375,
                    "https://www.sevenbridges.com/y": -280
                },
                {
                    "id": "#main/Log.progress.out",
                    "outputSource": [
                        "#main/star_mapping_pe/Log.progress.out"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://www.sevenbridges.com/x": -97.39886474609375,
                    "https://www.sevenbridges.com/y": -150
                },
                {
                    "id": "#main/Log.out",
                    "outputSource": [
                        "#main/star_mapping_pe/Log.out"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "https://www.sevenbridges.com/x": -82,
                    "https://www.sevenbridges.com/y": 9
                },
                {
                    "id": "#main/aligned",
                    "outputSource": [
                        "#main/star_mapping_pe/aligned"
                    ],
                    "type": "File",
                    "https://www.sevenbridges.com/x": -86,
                    "https://www.sevenbridges.com/y": 169
                },
                {
                    "id": "#main/output_quantdir",
                    "outputSource": [
                        "#main/salmon_quant/output_quantdir"
                    ],
                    "type": "Directory",
                    "https://www.sevenbridges.com/x": -74,
                    "https://www.sevenbridges.com/y": -627
                }
            ],
            "steps": [
                {
                    "id": "#main/star_mapping_pe",
                    "in": [
                        {
                            "id": "#main/star_mapping_pe/fq1",
                            "source": "#main/fq1_unmapped"
                        },
                        {
                            "id": "#main/star_mapping_pe/fq2",
                            "source": "#main/fq2_unmapped"
                        },
                        {
                            "id": "#main/star_mapping_pe/genomeDir",
                            "source": "#main/genomeDir_singlevirus"
                        },
                        {
                            "id": "#main/star_mapping_pe/nthreads",
                            "source": "#main/runThreadN"
                        },
                        {
                            "id": "#main/star_mapping_pe/outFileNamePrefix",
                            "source": "#main/outFileNamePrefix_star"
                        },
                        {
                            "id": "#main/star_mapping_pe/outSAMtype",
                            "default": "BAM SortedByCoordinate "
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/star_mapping_pe/aligned"
                        },
                        {
                            "id": "#main/star_mapping_pe/bamRemDups"
                        },
                        {
                            "id": "#main/star_mapping_pe/mappingstats"
                        },
                        {
                            "id": "#main/star_mapping_pe/readspergene"
                        },
                        {
                            "id": "#main/star_mapping_pe/transcriptomesam"
                        },
                        {
                            "id": "#main/star_mapping_pe/Log.out"
                        },
                        {
                            "id": "#main/star_mapping_pe/Log.progress.out"
                        },
                        {
                            "id": "#main/star_mapping_pe/SJ.out.tab"
                        },
                        {
                            "id": "#main/star_mapping_pe/unmapped"
                        }
                    ],
                    "run": "#star_mapping-pe.cwl",
                    "label": "STAR mapping: running mapping jobs.",
                    "https://www.sevenbridges.com/x": -349,
                    "https://www.sevenbridges.com/y": -316
                },
                {
                    "id": "#main/salmon_quant",
                    "in": [
                        {
                            "id": "#main/salmon_quant/index",
                            "source": "#main/salmon_index_singlevirus"
                        },
                        {
                            "id": "#main/salmon_quant/inf1",
                            "source": "#main/fq1_unmapped"
                        },
                        {
                            "id": "#main/salmon_quant/inf2",
                            "source": "#main/fq2_unmapped"
                        },
                        {
                            "id": "#main/salmon_quant/libType",
                            "default": "A"
                        },
                        {
                            "id": "#main/salmon_quant/quantdir",
                            "source": "#main/quantdir"
                        },
                        {
                            "id": "#main/salmon_quant/runThreadN",
                            "source": "#main/runThreadN"
                        },
                        {
                            "id": "#main/salmon_quant/gcBias",
                            "default": true
                        },
                        {
                            "id": "#main/salmon_quant/validateMappings",
                            "default": true
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/salmon_quant/output_quantdir"
                        }
                    ],
                    "run": "#salmon-quant.cwl",
                    "https://www.sevenbridges.com/x": -282,
                    "https://www.sevenbridges.com/y": -625
                }
            ],
            "requirements": [],
            "https://www.sevenbridges.com/toolAuthor": "Yoshiaki Yasumizu"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://www.sevenbridges.com/"
    }
}
